# QTSIT
The official Repo for QTSIT

<!-- [![codecov](https://codecov.io/gh/QTSIT/qtsit/branch/main/graph/badge.svg?token=qtsit_token_here)](https://codecov.io/gh/QTSIT/qtsit) -->
[![Test for documents](https://github.com/QTSIT/qtsit/actions/workflows/docs.yml/badge.svg)](https://github.com/QTSIT/qtsit/actions/workflows/docs.yml)
[![Code Formatting](https://github.com/QTSIT/qtsit/actions/workflows/formatting.yml/badge.svg)](https://github.com/QTSIT/qtsit/actions/workflows/formatting.yml)

## Install it from PyPI

```bash
pip install qtsit
```

## Usage

```py
from qtsit import BaseClass
from qtsit import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m qtsit
#or
$ qtsit
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
